@@ -1,6 +1,7 @@
 package common
 
 import (
+	"k8s.io/apimachinery/pkg/api/resource"
 	"os"
 
 	eventingv1alpha1 "knative.dev/operator/pkg/apis/operator/v1alpha1"
@@ -10,6 +11,7 @@ import (
 func MutateEventing(ke *eventingv1alpha1.KnativeEventing, c client.Client) error {
 	stages := []func(*eventingv1alpha1.KnativeEventing, client.Client) error{
 		eventingImagesFromEnviron,
+		ensureEventingWebhookMemoryLimit,
 	}
 	for _, stage := range stages {
 		if err := stage(ke, c); err != nil {
@@ -30,3 +32,7 @@ func eventingImagesFromEnviron(ke *eventingv1alpha1.KnativeEventing, _ client.Cl
 	log.Info("Setting", "registry", ke.Spec.Registry)
 	return nil
 }
+
+func ensureEventingWebhookMemoryLimit(ks *eventingv1alpha1.KnativeEventing, c client.Client) error {
+	return EnsureContainerMemoryLimit(&ks.Spec.CommonSpec, "eventing-webhook", resource.MustParse("1024Mi"))
+}
