@@ -17,11 +17,12 @@ import (
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/client-go/kubernetes/scheme"
-	"knative.dev/pkg/apis/istio/v1alpha3"
-	"knative.dev/serving-operator/pkg/apis/serving/v1alpha1"
+	"knative.dev/operator/pkg/apis/operator/v1alpha1"
 	"sigs.k8s.io/controller-runtime/pkg/client/fake"
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 	logf "sigs.k8s.io/controller-runtime/pkg/runtime/log"
+
+	"github.com/openshift-knative/serverless-operator/knative-operator/pkg/controller/knativeserving/dashboard"
 )
 
 var (
@@ -40,13 +41,6 @@ var (
 		},
 	}
 
-	defaultVirtualService = v1alpha3.VirtualService{
-		ObjectMeta: metav1.ObjectMeta{
-			Name:      "vsName",
-			Namespace: "vsNamespace",
-		},
-	}
-
 	defaultRequest = reconcile.Request{
 		NamespacedName: types.NamespacedName{Namespace: "knative-serving", Name: "knative-serving"},
 	}
@@ -74,12 +68,19 @@ var (
 			},
 		},
 	}
+
+	dashboardNamespace = corev1.Namespace{
+		ObjectMeta: metav1.ObjectMeta{
+			Name: dashboard.ConfigManagedNamespace,
+		},
+	}
 )
 
 func init() {
 	os.Setenv("OPERATOR_NAME", "TEST_OPERATOR")
 	os.Setenv("KOURIER_MANIFEST_PATH", "kourier/testdata/kourier-latest.yaml")
 	os.Setenv("CONSOLECLIDOWNLOAD_MANIFEST_PATH", "consoleclidownload/testdata/console_cli_download_kn_resources.yaml")
+	os.Setenv("DASHBOARD_MANIFEST_PATH", "dashboard/testdata/grafana-dash-knative.yaml")
 }
 
 // TestKourierReconcile runs Reconcile to verify if expected Kourier resources are deleted.
@@ -118,14 +119,14 @@ func TestKourierReconcile(t *testing.T) {
 			ingress := &defaultIngress
 			knRoute := &defaultKnRoute
 			ccd := &consolev1.ConsoleCLIDownload{}
+			ns := &dashboardNamespace
 
-			initObjs := []runtime.Object{ks, ingress, knRoute}
+			initObjs := []runtime.Object{ks, ingress, knRoute, ns}
 
 			// Register operator types with the runtime scheme.
 			s := scheme.Scheme
 			s.AddKnownTypes(v1alpha1.SchemeGroupVersion, ks)
 			s.AddKnownTypes(configv1.SchemeGroupVersion, ingress)
-			s.AddKnownTypes(v1alpha3.SchemeGroupVersion, &v1alpha3.VirtualServiceList{})
 			s.AddKnownTypes(routev1.GroupVersion, knRoute)
 			s.AddKnownTypes(consolev1.GroupVersion, ccd)
 
@@ -186,80 +187,6 @@ func TestKourierReconcile(t *testing.T) {
 	}
 }
 
-// TestKourierReconcile runs Reconcile to verify if orphaned virtualservice is deleted or not
-func TestDeleteVirtualServiceReconcile(t *testing.T) {
-	logf.SetLogger(logf.ZapLogger(true))
-
-	tests := []struct {
-		name        string
-		labels      map[string]string
-		annotations map[string]string
-		deleted     bool
-	}{
-		{
-			name:        "delete virtualservice with expected label and annotation",
-			labels:      map[string]string{routeLabelKey: "something", "a": "b"},
-			annotations: map[string]string{ingressClassKey: istioIngressClass, "c": "d"},
-			deleted:     true,
-		},
-		{
-			name:        "do not delete virtualservice with expected label but without annotation",
-			labels:      map[string]string{routeLabelKey: "something", "a": "b"},
-			annotations: map[string]string{"c": "d"},
-			deleted:     false,
-		},
-		{
-			name:        "do not delete virtualservice with expected annotation but without label",
-			labels:      map[string]string{"a": "b"},
-			annotations: map[string]string{ingressClassKey: istioIngressClass, "c": "d"},
-			deleted:     false,
-		},
-	}
-
-	for _, test := range tests {
-		t.Run(test.name, func(t *testing.T) {
-			ks := &defaultKnativeServing
-			ingress := &defaultIngress
-			vs := &defaultVirtualService
-			knRoute := &defaultKnRoute
-
-			// Set annotation and label for test
-			vs.SetAnnotations(test.annotations)
-			vs.SetLabels(test.labels)
-
-			initObjs := []runtime.Object{ks, ingress, vs, knRoute}
-
-			// Register operator types with the runtime scheme.
-			s := scheme.Scheme
-			s.AddKnownTypes(v1alpha1.SchemeGroupVersion, ks)
-			s.AddKnownTypes(configv1.SchemeGroupVersion, ingress)
-			s.AddKnownTypes(v1alpha3.SchemeGroupVersion, vs)
-			s.AddKnownTypes(routev1.GroupVersion, knRoute)
-
-			cl := fake.NewFakeClient(initObjs...)
-			r := &ReconcileKnativeServing{client: cl, scheme: s}
-
-			if _, err := r.Reconcile(defaultRequest); err != nil {
-				t.Fatalf("reconcile: (%v)", err)
-			}
-
-			// Check if VirtualService is deleted.
-			refetched := &v1alpha3.VirtualService{}
-			err := cl.Get(context.TODO(), types.NamespacedName{Name: "vsName", Namespace: "vsNamespace"}, refetched)
-			if test.deleted {
-				if !errors.IsNotFound(err) {
-					t.Fatalf("get: (%v)", err)
-				}
-			}
-			if !test.deleted {
-				if err != nil {
-					t.Fatalf("get: (%v)", err)
-				}
-			}
-		})
-	}
-}
-
 func TestCustomCertsConfigMap(t *testing.T) {
 	ks := &v1alpha1.KnativeServing{
 		ObjectMeta: metav1.ObjectMeta{
